==> kimageannotator_0.4.0.orig.tar.gz: kImageAnnotator-0.4.0/translations/kImageAnnotator_no.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Tilpass</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Ta til forgrunnen</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Ta forover</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Send bakover</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Send bakerst</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Velg dette</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Lim inn</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationSettings</name>
    <message>
        <source>Color</source>
        <translation>Farge</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Bredde</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Tekstfarge</translation>
    </message>
    <message>
        <source>Font Size</source>
        <translation>Skriftstørrelse</translation>
    </message>
    <message>
        <source>Starting Number</source>
        <translation>Startnummer</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Lukk andre</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Lukk alle</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Lukk alle til venstre</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Lukk alle til høyre</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Crop</source>
        <translation>Beskjær</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>B:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation type="unfinished">Kantlinje og utfyllingssynlighet</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation type="unfinished">Rammelinje og utfylling</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation type="unfinished">Rammelinje og ingen utfylling</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation type="unfinished">Ingen rammelinje og ingen utfylling</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Border</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Skaler bilde</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Behold sideforhold</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Bredde:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Høyde:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Piksel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Prosent</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation type="unfinished">Klistremerke</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Velg</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Penn</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Tall</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Peker-rektangel</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Peker-ellipse</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Peker-penn</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Pil</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Dobbelpil</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linje</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Tilsløring</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rektangel</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Nummerpeker</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Klistremerke</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomIndicator</name>
    <message>
        <source>Zoom Level</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kimageannotator_0.6.0.orig.tar.gz: kImageAnnotator-0.6.0/translations/kImageAnnotator_no.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Tilpass</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Ta til forgrunnen</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Ta forover</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Send bakover</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Send bakerst</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Velg dette</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Lim inn</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation type="unfinished">Farge</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation type="unfinished">Tekstfarge</translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="unfinished">Bredde</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation type="unfinished">Såtall</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation type="unfinished">Dekkevnefaktor</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Lukk andre</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Lukk alle</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Lukk alle til venstre</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Lukk alle til høyre</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>B:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished">Bruk</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation type="unfinished">Kantlinje og utfyllingssynlighet</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation type="unfinished">Kantlinje og utfylling</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation type="unfinished">Kantlinje og ingen utfylling</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation type="unfinished">Ingen kantlinje og ingen utfylling</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation type="unfinished">Skriftstørrelse</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Underline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Bildeeffekter</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Ingen effekt</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Kastskygge</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Gråskala</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Kantlinje</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Begrenset</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation type="unfinished">Påtvinger bruk av bakgrunnsbilde
i kanvas når påslått.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation type="unfinished">X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation type="unfinished">Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation type="unfinished">B:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation type="unfinished">H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Bruk</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Avbryt</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>180°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Avbryt</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Skaler bilde</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Behold sideforhold</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Bredde:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Høyde:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Piksel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Prosent</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation type="unfinished">Klistremerke</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Velg</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Penn</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Tall</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Peker-rektangel</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Peker-ellipse</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Peker-penn</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Pil</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Dobbelpil</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linje</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Tilsløring</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rektangel</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Nummerpeker</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Klistremerke</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pikseler</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Tekstpeker</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Tekstpil</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Nummerpil</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Dupliser</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
